==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/petitions/lang/petitions_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vous allez supprimer toutes les signatures de cette p&eacute;tition. &Ecirc;tes-vous sur de vouloir continuer ?', # NEW
	'aucune_signature' => 'Aucune signature', # NEW

	// B
	'bouton_checkbox_envoi_message' => 'possibilit&eacute; d\'envoyer un message', # NEW
	'bouton_checkbox_indiquer_site' => 'indiquer obligatoirement un site web', # NEW
	'bouton_checkbox_signature_unique_email' => 'une seule signature par adresse email', # NEW
	'bouton_checkbox_signature_unique_site' => 'une seule signature par site web', # NEW

	// F
	'filtre' => 'Filtre :', # NEW
	'form_pet_adresse_site' => 'Adresa site-ului dumneavoastră', # MODIF
	'form_pet_aucune_signature' => 'Nici o semnătură nu corespunde acestui cod...',
	'form_pet_confirmation' => 'Vă rugăm să confirmaţi semnătura dumneavoastră :',
	'form_pet_deja_signe' => 'Aţi semnat deja acest text.',
	'form_pet_envoi_mail_confirmation' => 'Un email de confirmare tocmai v-a fost trimis la adresa @email@. Pentru a valida semnătura dumneavoastră, va trebui să vizitaţi adresa de web menţionată in email.', # MODIF
	'form_pet_mail_confirmation' => 'Bună ziua,

Aţi cerut să semnaţi petiţia :
@titre@.

Aţi furnizat informaţiile următoare :
    Nume: @nom_email@
    Site: @nom_site@ - @url_site@


IMPORTANT...
Pentru a valida semnătura, trebuie să vizitaţi
adresa de mai jos (în caz contrat, cererea dumneavoastră va fi refuzată) :

    @url@


Mulţumim pentru participarea dumneavoastră
',
	'form_pet_message_commentaire' => 'Un mesaj, un comentariu ?', # MODIF
	'form_pet_nom_site2' => 'Numele site-ului dumneavoastră de Web', # MODIF
	'form_pet_probleme_liens' => 'Vă rugăm să reluati introducerea mesajului - suprimaţi legăturile hipertext.',
	'form_pet_probleme_technique' => 'Datorită unor probleme tehnice, semnăturile sunt deocamdată suspendate.',
	'form_pet_signature_validee' => 'Semnătura dumneavoastră este validată. Mulţumiri  !',
	'form_pet_site_deja_enregistre' => 'Acest site este deja înregistrat',
	'form_pet_url_invalide' => 'Adresa URL indicată nu este valabilă.',
	'form_pet_votre_email' => 'Adresa dumneavoastră de email',
	'form_pet_votre_nom' => 'Numele sau pseudonimul dumneavoastră', # MODIF
	'form_pet_votre_site' => 'Dacă aveţi un site Web, puteţi să-l indicaţi mai jos',

	// I
	'icone_relancer_signataire' => 'Relancer le signataire', # NEW
	'icone_relancer_signataires' => 'Relancer les signataires', # NEW
	'icone_suivi_petitions' => 'Suivre/g&eacute;rer les p&eacute;titions', # NEW
	'icone_supprimer_signature' => 'Supprimer cette signature', # NEW
	'icone_supprimer_signatures' => 'Supprimer les signatures', # NEW
	'icone_valider_signature' => 'Valider cette signature', # NEW
	'icone_valider_signatures' => 'Valider les signatures', # NEW
	'info_adresse_email' => 'ADRESA EMAIL :',
	'info_fonctionnement_petition' => 'Fonctionnement de la p&eacute;tition :', # NEW
	'info_signature_supprimee' => 'Semnătură suprimată',
	'info_signature_supprimee_erreur' => 'Eroare : acest cod de ştergere nu corespunde nici unei semnături',
	'info_site_web' => 'SITE WEB :',
	'info_texte_message' => 'Textul mesajului dumneavoastră :',

	// L
	'lien_reponse_article' => 'Răspuns la articol',

	// N
	'nombre_signatures' => '@nb@ signatures', # NEW

	// S
	'sans_nom' => 'Anonyme', # NEW
	'signatures_article' => 'Signatures de l\'article :', # NEW
	'signatures_aucune' => 'Aucune', # NEW
	'signatures_meme_auteur' => 'Les signatures du m', # NEW
	'signatures_meme_site' => 'Les signatures avec le m', # NEW
	'signatures_poubelle' => 'Supprim&eacute;es', # NEW
	'signatures_prop' => 'En attente', # NEW
	'signatures_publie' => 'Confirm&eacute;es', # NEW
	'signatures_recherche_label' => 'Rechercher des signatures&nbsp;:', # NEW
	'signatures_toutes' => 'Toutes', # NEW
	'statut_poubelle' => 'Supprim&eacute;e', # NEW
	'statut_prop' => 'En attente de validation', # NEW
	'statut_publie' => 'Confirm&eacute;e', # NEW

	// T
	'texte_descriptif_petition' => 'Descriptif de la p&eacute;tition', # NEW
	'titre_page_controle_petition' => 'Suivi des p&eacute;titions', # NEW
	'titre_petition' => 'P&eacute;tition', # NEW
	'titre_petitions' => 'P&eacute;titions', # NEW
	'titre_selection_action' => 'Sélection', # NEW
	'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
	'titre_signatures_publie' => 'Signatures confirm&eacute;es', # NEW
	'titre_suivi_petition' => 'Suivi des p&eacute;titions', # NEW
	'tout_voir' => 'Voir toutes les signatures', # NEW

	// U
	'une_signature' => '1 signature', # NEW

	// V
	'voir_signatures_objet' => 'Voir les signatures' # NEW
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/petitions/lang/petitions_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activaţi petiţia',
	'bouton_radio_pas_petition' => 'Fără petiţie',
	'bouton_radio_petition_activee' => 'Petiţie activată',
	'bouton_radio_supprimer_petition' => 'Ştergeţi petiţia',

	// F
	'form_pet_adresse_site' => 'Adresa site-ului dumneavoastră', # MODIF
	'form_pet_aucune_signature' => 'Nici o semnătură nu corespunde acestui cod...', # MODIF
	'form_pet_confirmation' => 'Vă rugăm să confirmaţi semnătura dumneavoastră :',
	'form_pet_deja_signe' => 'Aţi semnat deja acest text.',
	'form_pet_envoi_mail_confirmation' => 'Un email de confirmare tocmai v-a fost trimis la adresa @email@. Pentru a valida semnătura dumneavoastră, va trebui să vizitaţi adresa de web menţionată in email.', # MODIF
	'form_pet_mail_confirmation' => 'Bună ziua,

Aţi cerut să semnaţi petiţia :
@titre@.

Aţi furnizat informaţiile următoare :
    Nume: @nom_email@
    Site: @nom_site@ - @url_site@


IMPORTANT...
Pentru a valida semnătura, trebuie să vizitaţi
adresa de mai jos (în caz contrat, cererea dumneavoastră va fi refuzată) :

    @url@


Mulţumim pentru participarea dumneavoastră
',
	'form_pet_nom_site2' => 'Numele site-ului dumneavoastră de Web', # MODIF
	'form_pet_probleme_liens' => 'Vă rugăm să reluati introducerea mesajului - suprimaţi legăturile hipertext.',
	'form_pet_probleme_technique' => 'Datorită unor probleme tehnice, semnăturile sunt deocamdată suspendate.',
	'form_pet_signature_validee' => 'Semnătura dumneavoastră este validată. Mulţumiri !',
	'form_pet_site_deja_enregistre' => 'Acest site este deja înregistrat',
	'form_pet_url_invalide' => 'Adresa URL indicată nu este valabilă.',
	'form_pet_votre_email' => 'Adresa dumneavoastră de email',
	'form_pet_votre_nom' => 'Numele sau pseudonimul dumneavoastră', # MODIF
	'form_pet_votre_site' => 'Dacă aveţi un site Web, puteţi să-l indicaţi mai jos',

	// I
	'info_adresse_email' => 'ADRESA EMAIL :',
	'info_signature_supprimee' => 'Semnătură suprimată',
	'info_signature_supprimee_erreur' => 'Eroare : acest cod de ştergere nu corespunde nici unei semnături', # MODIF
	'info_site_web' => 'SITE WEB :',

	// L
	'lien_reponse_article' => 'Răspuns la articol'
);

?>
